from skidl import Pin, Part, SchLib, SKIDL, TEMPLATE

SKIDL_lib_version = '0.0.1'

powerint = SchLib(tool=SKIDL).add_parts(*[
        Part(name='CAP002DG',dest=TEMPLATE,tool=SKIDL,keywords='CapZero Automatic Capacitor Discarger 1000V 5000nF',description='CapZero Automatic Capacitor Discarger, Vdss 1000V, Cmax 5000nF, SO8',ref_prefix='U',num_units=1,fplist=['SO-8*'],do_erc=True,aliases=['CAP003DG', 'CAP004DG', 'CAP005DG', 'CAP006DG', 'CAP007DG', 'CAP008DG', 'CAP009DG', 'CAP012DG', 'CAP013DG', 'CAP014DG', 'CAP015DG', 'CAP016DG', 'CAP017DG', 'CAP018DG', 'CAP019DG'],pins=[
            Pin(num='1',name='~',func=Pin.PASSIVE,do_erc=True),
            Pin(num='2',name='~',func=Pin.PASSIVE,do_erc=True),
            Pin(num='3',name='~',func=Pin.PASSIVE,do_erc=True),
            Pin(num='4',name='~',func=Pin.PASSIVE,do_erc=True),
            Pin(num='5',name='~',func=Pin.PASSIVE,do_erc=True),
            Pin(num='6',name='~',func=Pin.PASSIVE,do_erc=True),
            Pin(num='7',name='~',func=Pin.PASSIVE,do_erc=True),
            Pin(num='8',name='~',func=Pin.PASSIVE,do_erc=True)]),
        Part(name='LNK302D',dest=TEMPLATE,tool=SKIDL,keywords='Lowest Component Count, Energy-Efficient Off-Line Switcher IC',description='LinkSwitch-TN Family, 360mA Output Current, SO-8C',ref_prefix='U',num_units=1,fplist=['SO-8B*'],do_erc=True,aliases=['LNK304D', 'LNK305D', 'LNK306D'],pins=[
            Pin(num='1',name='BP',do_erc=True),
            Pin(num='2',name='FB',do_erc=True),
            Pin(num='4',name='D',func=Pin.OPENCOLL,do_erc=True),
            Pin(num='5',name='S',func=Pin.OPENEMIT,do_erc=True),
            Pin(num='6',name='S',func=Pin.OPENEMIT,do_erc=True),
            Pin(num='7',name='S',func=Pin.OPENEMIT,do_erc=True),
            Pin(num='8',name='S',func=Pin.OPENEMIT,do_erc=True)]),
        Part(name='LNK302G',dest=TEMPLATE,tool=SKIDL,keywords='Lowest Component Count, Energy-Efficient Off-Line Switcher IC',description='LinkSwitch-TN Family, 360mA Output Current, SMD-8B',ref_prefix='U',num_units=1,fplist=['SMD-8B*'],do_erc=True,aliases=['LNK304G', 'LNK305G', 'LNK306G'],pins=[
            Pin(num='1',name='S',func=Pin.OPENEMIT,do_erc=True),
            Pin(num='2',name='S',func=Pin.OPENEMIT,do_erc=True),
            Pin(num='3',name='BP',do_erc=True),
            Pin(num='4',name='FB',do_erc=True),
            Pin(num='5',name='D',func=Pin.OPENCOLL,do_erc=True),
            Pin(num='7',name='S',func=Pin.OPENEMIT,do_erc=True),
            Pin(num='8',name='S',func=Pin.OPENEMIT,do_erc=True)]),
        Part(name='LNK302P',dest=TEMPLATE,tool=SKIDL,keywords='Lowest Component Count, Energy-Efficient Off-Line Switcher IC',description='LinkSwitch-TN Family, 360mA Output Current, DIP-8B',ref_prefix='U',num_units=1,fplist=['PDIP-8B*'],do_erc=True,aliases=['LNK304P', 'LNK305P', 'LNK306P'],pins=[
            Pin(num='1',name='S',func=Pin.OPENEMIT,do_erc=True),
            Pin(num='2',name='S',func=Pin.OPENEMIT,do_erc=True),
            Pin(num='3',name='BP',do_erc=True),
            Pin(num='4',name='FB',do_erc=True),
            Pin(num='5',name='D',func=Pin.OPENCOLL,do_erc=True),
            Pin(num='7',name='S',func=Pin.OPENEMIT,do_erc=True),
            Pin(num='8',name='S',func=Pin.OPENEMIT,do_erc=True)]),
        Part(name='LNK362D',dest=TEMPLATE,tool=SKIDL,keywords='Energy Effi cient, Low Power Off-Line Switcher IC',description='LinkSwitch-XT Family, 6W Output Power, SO-8C',ref_prefix='U',num_units=1,fplist=['SO-8C*'],do_erc=True,aliases=['LNK363D', 'LNK364D'],pins=[
            Pin(num='1',name='BP',do_erc=True),
            Pin(num='2',name='FB',do_erc=True),
            Pin(num='4',name='D',func=Pin.OPENCOLL,do_erc=True),
            Pin(num='5',name='S',func=Pin.OPENEMIT,do_erc=True),
            Pin(num='6',name='S',func=Pin.OPENEMIT,do_erc=True),
            Pin(num='7',name='S',func=Pin.OPENEMIT,do_erc=True),
            Pin(num='8',name='S',func=Pin.OPENEMIT,do_erc=True)]),
        Part(name='LNK362G',dest=TEMPLATE,tool=SKIDL,keywords='Energy Effi cient, Low Power Off-Line Switcher IC',description='LinkSwitch-XT Family, 6W Output Power, SMD-8B',ref_prefix='U',num_units=1,fplist=['SMD-8B*'],do_erc=True,aliases=['LNK363G', 'LNK364G'],pins=[
            Pin(num='1',name='S',func=Pin.OPENEMIT,do_erc=True),
            Pin(num='2',name='S',func=Pin.OPENEMIT,do_erc=True),
            Pin(num='3',name='BP',do_erc=True),
            Pin(num='4',name='FB',do_erc=True),
            Pin(num='5',name='D',func=Pin.OPENCOLL,do_erc=True),
            Pin(num='7',name='S',func=Pin.OPENEMIT,do_erc=True),
            Pin(num='8',name='S',func=Pin.OPENEMIT,do_erc=True)]),
        Part(name='LNK362P',dest=TEMPLATE,tool=SKIDL,keywords='Energy Effi cient, Low Power Off-Line Switcher IC',description='LinkSwitch-XT Family, 6W Output Power, DIP-8B',ref_prefix='U',num_units=1,fplist=['PDIP-8B*'],do_erc=True,aliases=['LNK363P', 'LNK364P'],pins=[
            Pin(num='1',name='S',func=Pin.OPENEMIT,do_erc=True),
            Pin(num='2',name='S',func=Pin.OPENEMIT,do_erc=True),
            Pin(num='3',name='BP',do_erc=True),
            Pin(num='4',name='FB',do_erc=True),
            Pin(num='5',name='D',func=Pin.OPENCOLL,do_erc=True),
            Pin(num='7',name='S',func=Pin.OPENEMIT,do_erc=True),
            Pin(num='8',name='S',func=Pin.OPENEMIT,do_erc=True)]),
        Part(name='LNK403EG',dest=TEMPLATE,tool=SKIDL,keywords='LED Driver IC, Single-Stage PFC and Primary-Side Constant Current Control',description='LinkSwitch-PH Family, 78W Output Power, eSIP-7C',ref_prefix='U',num_units=1,fplist=['sSIP-7C*'],do_erc=True,aliases=['LNK404EG', 'LNK405EG', 'LNK406EG', 'LNK407EG', 'LNK408EG', 'LNK409EG', 'LNK410EG', 'LNK413EG', 'LNK414EG', 'LNK415EG', 'LNK416EG', 'LNK417EG', 'LNK418EG', 'LNK419EG', 'LNK420EG'],pins=[
            Pin(num='1',name='R',do_erc=True),
            Pin(num='2',name='V',do_erc=True),
            Pin(num='3',name='FB',do_erc=True),
            Pin(num='4',name='BP',do_erc=True),
            Pin(num='5',name='S',func=Pin.OPENEMIT,do_erc=True),
            Pin(num='7',name='D',func=Pin.OPENCOLL,do_erc=True)]),
        Part(name='LNK403LG',dest=TEMPLATE,tool=SKIDL,keywords='LED Driver IC, Single-Stage PFC and Primary-Side Constant Current Control',description='LinkSwitch-PH Family, 78W Output Power, eSIP-7F',ref_prefix='U',num_units=1,fplist=['eSIP-7F*'],do_erc=True,aliases=['LNK404LG', 'LNK405LG', 'LNK406LG', 'LNK407LG', 'LNK408LG', 'LNK409LG', 'LNK410LG', 'LNK413LG', 'LNK414LG', 'LNK415LG', 'LNK416LG', 'LNK417LG', 'LNK418LG', 'LNK419LG', 'LNK420LG'],pins=[
            Pin(num='1',name='R',do_erc=True),
            Pin(num='2',name='V',do_erc=True),
            Pin(num='3',name='FB',do_erc=True),
            Pin(num='4',name='BP',do_erc=True),
            Pin(num='5',name='S',func=Pin.OPENEMIT,do_erc=True),
            Pin(num='7',name='D',func=Pin.OPENCOLL,do_erc=True)]),
        Part(name='LNK454D',dest=TEMPLATE,tool=SKIDL,keywords='LED Driver IC with TRIAC Dimming, Single-Stage PFC and Constant Current Control for Non-Isolated Applications',description='LinkSwitch-PL Family, 8W Output Power, SO-8C',ref_prefix='U',num_units=1,fplist=['SO-8C*'],do_erc=True,aliases=['LNK456D', 'LNK457D'],pins=[
            Pin(num='1',name='FB',do_erc=True),
            Pin(num='2',name='BP',do_erc=True),
            Pin(num='4',name='D',func=Pin.OPENCOLL,do_erc=True),
            Pin(num='5',name='S',func=Pin.OPENEMIT,do_erc=True),
            Pin(num='6',name='S',func=Pin.OPENCOLL,do_erc=True),
            Pin(num='7',name='S',func=Pin.OPENCOLL,do_erc=True),
            Pin(num='8',name='S',func=Pin.OPENCOLL,do_erc=True)]),
        Part(name='LNK457K',dest=TEMPLATE,tool=SKIDL,keywords='LED Driver IC with TRIAC Dimming, Single-Stage PFC and Constant Current Control for Non-Isolated Applications',description='LinkSwitch-PL Family, 16W Output Power, eSOP-12B',ref_prefix='U',num_units=1,fplist=['eSOP-12B*'],do_erc=True,aliases=['LNK458K', 'LNK460K'],pins=[
            Pin(num='1',name='NC',func=Pin.NOCONNECT,do_erc=True),
            Pin(num='2',name='FB',do_erc=True),
            Pin(num='3',name='BP',do_erc=True),
            Pin(num='4',name='NC',func=Pin.NOCONNECT,do_erc=True),
            Pin(num='6',name='D',func=Pin.OPENCOLL,do_erc=True),
            Pin(num='7',name='S',func=Pin.OPENCOLL,do_erc=True),
            Pin(num='8',name='S',func=Pin.OPENCOLL,do_erc=True),
            Pin(num='9',name='S',func=Pin.OPENCOLL,do_erc=True),
            Pin(num='10',name='S',func=Pin.OPENEMIT,do_erc=True),
            Pin(num='11',name='S',func=Pin.OPENEMIT,do_erc=True),
            Pin(num='12',name='S',func=Pin.OPENEMIT,do_erc=True),
            Pin(num='13',name='S',func=Pin.OPENEMIT,do_erc=True)]),
        Part(name='LNK457V',dest=TEMPLATE,tool=SKIDL,keywords='LED Driver IC with TRIAC Dimming, Single-Stage PFC and Constant Current Control for Non-Isolated Applications',description='LinkSwitch-PL Family, 8W Output Power, eDIP-12B',ref_prefix='U',num_units=1,fplist=['eDIP-12B*'],do_erc=True,aliases=['LNK458V', 'LNK460V'],pins=[
            Pin(num='1',name='NC',func=Pin.NOCONNECT,do_erc=True),
            Pin(num='2',name='FB',do_erc=True),
            Pin(num='3',name='BP',do_erc=True),
            Pin(num='4',name='NC',func=Pin.NOCONNECT,do_erc=True),
            Pin(num='6',name='D',func=Pin.OPENCOLL,do_erc=True),
            Pin(num='7',name='S',func=Pin.OPENCOLL,do_erc=True),
            Pin(num='8',name='S',func=Pin.OPENCOLL,do_erc=True),
            Pin(num='9',name='S',func=Pin.OPENCOLL,do_erc=True),
            Pin(num='10',name='S',func=Pin.OPENEMIT,do_erc=True),
            Pin(num='11',name='S',func=Pin.OPENEMIT,do_erc=True),
            Pin(num='12',name='S',func=Pin.OPENEMIT,do_erc=True)]),
        Part(name='LNK562D',dest=TEMPLATE,tool=SKIDL,keywords='Energy Efficient Off-Line Switcher IC for Linear Transformer Replacement',description='LinkSwitch-LP Family, 3W Output Power, SO-8C',ref_prefix='U',num_units=1,fplist=['SO-8C*'],do_erc=True,aliases=['LNK563D', 'LNK564D'],pins=[
            Pin(num='1',name='BP',do_erc=True),
            Pin(num='2',name='FB',do_erc=True),
            Pin(num='4',name='D',func=Pin.OPENCOLL,do_erc=True),
            Pin(num='5',name='S',func=Pin.OPENEMIT,do_erc=True),
            Pin(num='6',name='S',func=Pin.OPENEMIT,do_erc=True),
            Pin(num='7',name='S',func=Pin.OPENEMIT,do_erc=True),
            Pin(num='8',name='S',func=Pin.OPENEMIT,do_erc=True)]),
        Part(name='LNK562G',dest=TEMPLATE,tool=SKIDL,keywords='Energy Efficient Off-Line Switcher IC for Linear Transformer Replacement',description='LinkSwitch-LP Family, 3W Output Power, SMD-8B',ref_prefix='U',num_units=1,fplist=['SMD-8B*'],do_erc=True,aliases=['LNK563G', 'LNK564G'],pins=[
            Pin(num='1',name='S',func=Pin.OPENEMIT,do_erc=True),
            Pin(num='2',name='S',func=Pin.OPENEMIT,do_erc=True),
            Pin(num='3',name='BP',do_erc=True),
            Pin(num='4',name='FB',do_erc=True),
            Pin(num='5',name='D',func=Pin.OPENCOLL,do_erc=True),
            Pin(num='7',name='S',func=Pin.OPENEMIT,do_erc=True),
            Pin(num='8',name='S',func=Pin.OPENEMIT,do_erc=True)]),
        Part(name='LNK562P',dest=TEMPLATE,tool=SKIDL,keywords='Energy Efficient Off-Line Switcher IC for Linear Transformer Replacement',description='LinkSwitch-LP Family, 3W Output Power, DIP-8B',ref_prefix='U',num_units=1,fplist=['PDIP-8B*'],do_erc=True,aliases=['LNK563P', 'LNK564P'],pins=[
            Pin(num='1',name='S',func=Pin.OPENEMIT,do_erc=True),
            Pin(num='2',name='S',func=Pin.OPENEMIT,do_erc=True),
            Pin(num='3',name='BP',do_erc=True),
            Pin(num='4',name='FB',do_erc=True),
            Pin(num='5',name='D',func=Pin.OPENCOLL,do_erc=True),
            Pin(num='7',name='S',func=Pin.OPENEMIT,do_erc=True),
            Pin(num='8',name='S',func=Pin.OPENEMIT,do_erc=True)]),
        Part(name='LNK603DG',dest=TEMPLATE,tool=SKIDL,keywords='Energy-Efficient, Accurate CV/CC Switcher for Adapters and Chargers',description='LinkSwitch-II Family, 6.1W Output Power, SO-8C',ref_prefix='U',num_units=1,fplist=['SO-8C*'],do_erc=True,aliases=['LNK604DG', 'LNK605DG', 'LNK606DG', 'LNK613DG', 'LNK614DG', 'LNK615DG', 'LNK616DG'],pins=[
            Pin(num='1',name='FB',do_erc=True),
            Pin(num='2',name='BP/M',do_erc=True),
            Pin(num='4',name='D',func=Pin.OPENCOLL,do_erc=True),
            Pin(num='5',name='S',func=Pin.OPENEMIT,do_erc=True),
            Pin(num='6',name='S',func=Pin.OPENEMIT,do_erc=True),
            Pin(num='7',name='S',func=Pin.OPENEMIT,do_erc=True),
            Pin(num='8',name='S',func=Pin.OPENEMIT,do_erc=True)]),
        Part(name='LNK603PG',dest=TEMPLATE,tool=SKIDL,keywords='Energy-Efficient, Accurate CV/CC Switcher for Adapters and Chargers',description='LinkSwitch-II Family, 6.1W Output Power, DIP-8C',ref_prefix='U',num_units=1,fplist=['PDIP-8C*'],do_erc=True,aliases=['LNK604PG', 'LNK605PG', 'LNK606PG', 'LNK613PG', 'LNK614PG', 'LNK615PG', 'LNK616PG'],pins=[
            Pin(num='1',name='FB',do_erc=True),
            Pin(num='2',name='BP/M',do_erc=True),
            Pin(num='4',name='D',func=Pin.OPENCOLL,do_erc=True),
            Pin(num='5',name='S',func=Pin.OPENEMIT,do_erc=True),
            Pin(num='6',name='S',func=Pin.OPENEMIT,do_erc=True),
            Pin(num='7',name='S',func=Pin.OPENEMIT,do_erc=True),
            Pin(num='8',name='S',func=Pin.OPENEMIT,do_erc=True)]),
        Part(name='LNK606GG',dest=TEMPLATE,tool=SKIDL,keywords='Energy-Efficient, Accurate CV/CC Switcher for Adapters and Chargers',description='LinkSwitch-II Family, 6.1W Output Power, SMD-8C',ref_prefix='U',num_units=1,fplist=['SMD-8C*'],do_erc=True,aliases=['LNK616GG'],pins=[
            Pin(num='1',name='FB',do_erc=True),
            Pin(num='2',name='BP/M',do_erc=True),
            Pin(num='4',name='D',func=Pin.OPENCOLL,do_erc=True),
            Pin(num='5',name='S',func=Pin.OPENEMIT,do_erc=True),
            Pin(num='6',name='S',func=Pin.OPENEMIT,do_erc=True),
            Pin(num='7',name='S',func=Pin.OPENEMIT,do_erc=True),
            Pin(num='8',name='S',func=Pin.OPENEMIT,do_erc=True)]),
        Part(name='LNK623DG',dest=TEMPLATE,tool=SKIDL,keywords='Energy-Efficient, Off-line Switcher with Accurate Primary-side Constant-Voltage Control',description='LinkSwitch-CV Family, 10W Output Power, SO-8C',ref_prefix='U',num_units=1,fplist=['SO-8C*'],do_erc=True,aliases=['LNK624DG', 'LNK625DG', 'LNK626DG'],pins=[
            Pin(num='1',name='FB',do_erc=True),
            Pin(num='2',name='BP',do_erc=True),
            Pin(num='4',name='D',func=Pin.OPENCOLL,do_erc=True),
            Pin(num='5',name='S',func=Pin.OPENCOLL,do_erc=True),
            Pin(num='6',name='S',func=Pin.OPENEMIT,do_erc=True),
            Pin(num='7',name='S',func=Pin.OPENEMIT,do_erc=True),
            Pin(num='8',name='S',func=Pin.OPENEMIT,do_erc=True)]),
        Part(name='LNK623PG',dest=TEMPLATE,tool=SKIDL,keywords='Energy-Efficient, Off-line Switcher with Accurate Primary-side Constant-Voltage Control',description='LinkSwitch-CV Family, 10W Output Power, DIP-8C',ref_prefix='U',num_units=1,fplist=['PDIP-8C*'],do_erc=True,aliases=['LNK624PG', 'LNK625PG', 'LNK626PG'],pins=[
            Pin(num='1',name='FB',do_erc=True),
            Pin(num='2',name='BP',do_erc=True),
            Pin(num='4',name='D',func=Pin.OPENCOLL,do_erc=True),
            Pin(num='5',name='S',func=Pin.OPENCOLL,do_erc=True),
            Pin(num='6',name='S',func=Pin.OPENEMIT,do_erc=True),
            Pin(num='7',name='S',func=Pin.OPENEMIT,do_erc=True),
            Pin(num='8',name='S',func=Pin.OPENEMIT,do_erc=True)]),
        Part(name='LNK632DG',dest=TEMPLATE,tool=SKIDL,keywords='Energy-Efficient, Accurate CV Switcher With CC Control for Adapters and Chargers',description='LinkSwitch-II Family, 3.1W Output Power, SO-8C',ref_prefix='U',num_units=1,fplist=['SO-8C*'],do_erc=True,pins=[
            Pin(num='1',name='FB',do_erc=True),
            Pin(num='2',name='BP/M',do_erc=True),
            Pin(num='4',name='D',func=Pin.OPENCOLL,do_erc=True),
            Pin(num='5',name='S',func=Pin.OPENEMIT,do_erc=True),
            Pin(num='6',name='S',func=Pin.OPENEMIT,do_erc=True),
            Pin(num='7',name='S',func=Pin.OPENEMIT,do_erc=True),
            Pin(num='8',name='S',func=Pin.OPENEMIT,do_erc=True)]),
        Part(name='TNY263G',dest=TEMPLATE,tool=SKIDL,keywords='Enhanced, Energy Efficient, Low Power Off-line Switcher',description='TinySwitch-II Family, 15W Output Power, SMD-8B',ref_prefix='U',num_units=1,fplist=['SMD-8B*'],do_erc=True,aliases=['TNY264G', 'TNY265G', 'TNY266G', 'TNY267G', 'TNY268G'],pins=[
            Pin(num='1',name='BP',do_erc=True),
            Pin(num='2',name='S',func=Pin.OPENEMIT,do_erc=True),
            Pin(num='3',name='S',func=Pin.OPENEMIT,do_erc=True),
            Pin(num='4',name='EN/UV',do_erc=True),
            Pin(num='5',name='D',func=Pin.OPENCOLL,do_erc=True),
            Pin(num='7',name='S',func=Pin.OPENEMIT,do_erc=True),
            Pin(num='8',name='S',func=Pin.OPENEMIT,do_erc=True)]),
        Part(name='TNY263P',dest=TEMPLATE,tool=SKIDL,keywords='Enhanced, Energy Efficient, Low Power Off-line Switcher',description='TinySwitch-II Family, 15W Output Power, DIP-8B',ref_prefix='U',num_units=1,fplist=['PDIP-8B*'],do_erc=True,aliases=['TNY264P', 'TNY265P', 'TNY266P', 'TNY267P', 'TNY268P'],pins=[
            Pin(num='1',name='BP',do_erc=True),
            Pin(num='2',name='S',func=Pin.OPENEMIT,do_erc=True),
            Pin(num='3',name='S',func=Pin.OPENEMIT,do_erc=True),
            Pin(num='4',name='EN/UV',do_erc=True),
            Pin(num='5',name='D',func=Pin.OPENCOLL,do_erc=True),
            Pin(num='7',name='S',func=Pin.OPENEMIT,do_erc=True),
            Pin(num='8',name='S',func=Pin.OPENEMIT,do_erc=True)]),
        Part(name='TNY274G',dest=TEMPLATE,tool=SKIDL,keywords='Energy-Efficient, Off-Line Switcher With Enhanced Flexibility and Extended Power Range',description='TinySwitch-III Family, 28.5W Output Power, SMD-8C',ref_prefix='U',num_units=1,fplist=['SMD-8C*'],do_erc=True,aliases=['TNY275G', 'TNY276G', 'TNY277G', 'TNY278G', 'TNY279G', 'TNY280G'],pins=[
            Pin(num='1',name='EN/UV',do_erc=True),
            Pin(num='2',name='BP/M',do_erc=True),
            Pin(num='4',name='D',func=Pin.OPENCOLL,do_erc=True),
            Pin(num='5',name='S',func=Pin.OPENEMIT,do_erc=True),
            Pin(num='6',name='S',func=Pin.OPENEMIT,do_erc=True),
            Pin(num='7',name='S',func=Pin.OPENEMIT,do_erc=True),
            Pin(num='8',name='S',func=Pin.OPENEMIT,do_erc=True)]),
        Part(name='TNY274P',dest=TEMPLATE,tool=SKIDL,keywords='Energy-Efficient, Off-Line Switcher With Enhanced Flexibility and Extended Power Range',description='TinySwitch-III Family, 28.5W Output Power, DIP-8C',ref_prefix='U',num_units=1,fplist=['PDIP-8C*'],do_erc=True,aliases=['TNY275P', 'TNY276P', 'TNY277P', 'TNY278P', 'TNY279P', 'TNY280P'],pins=[
            Pin(num='1',name='EN/UV',do_erc=True),
            Pin(num='2',name='BP/M',do_erc=True),
            Pin(num='4',name='D',func=Pin.OPENCOLL,do_erc=True),
            Pin(num='5',name='S',func=Pin.OPENEMIT,do_erc=True),
            Pin(num='6',name='S',func=Pin.OPENEMIT,do_erc=True),
            Pin(num='7',name='S',func=Pin.OPENEMIT,do_erc=True),
            Pin(num='8',name='S',func=Pin.OPENEMIT,do_erc=True)]),
        Part(name='TNY284D',dest=TEMPLATE,tool=SKIDL,keywords='Energy-Efficient, Off-Line Switcher With Line Compensated Overload Power',description='TinySwitch-4 Family, 19.5W Output Power, SO-8C',ref_prefix='U',num_units=1,fplist=['SO-8C*'],do_erc=True,aliases=['TNY285D', 'TNY286D', 'TNY287D', 'TNY288D'],pins=[
            Pin(num='1',name='EN/UV',do_erc=True),
            Pin(num='2',name='BP/M',do_erc=True),
            Pin(num='4',name='D',func=Pin.OPENCOLL,do_erc=True),
            Pin(num='5',name='S',func=Pin.OPENEMIT,do_erc=True),
            Pin(num='6',name='S',func=Pin.OPENEMIT,do_erc=True),
            Pin(num='7',name='S',func=Pin.OPENEMIT,do_erc=True),
            Pin(num='8',name='S',func=Pin.OPENEMIT,do_erc=True)]),
        Part(name='TNY284K',dest=TEMPLATE,tool=SKIDL,keywords='Energy-Efficient, Off-Line Switcher With Line Compensated Overload Power',description='TinySwitch-4 Family, 28.5W Output Power, eSOP-12B',ref_prefix='U',num_units=1,fplist=['eSOP-12B*'],do_erc=True,aliases=['TNY285K', 'TNY286K', 'TNY287K', 'TNY288K', 'TNY289K', 'TNY290K'],pins=[
            Pin(num='1',name='EN/UV',do_erc=True),
            Pin(num='2',name='BP/M',do_erc=True),
            Pin(num='3',name='NC',func=Pin.NOCONNECT,do_erc=True),
            Pin(num='4',name='NC',func=Pin.NOCONNECT,do_erc=True),
            Pin(num='6',name='D',func=Pin.OPENCOLL,do_erc=True),
            Pin(num='7',name='S',func=Pin.OPENEMIT,do_erc=True),
            Pin(num='8',name='S',func=Pin.OPENEMIT,do_erc=True),
            Pin(num='9',name='S',func=Pin.OPENEMIT,do_erc=True),
            Pin(num='10',name='S',func=Pin.OPENEMIT,do_erc=True),
            Pin(num='11',name='S',func=Pin.OPENEMIT,do_erc=True),
            Pin(num='12',name='S',func=Pin.OPENEMIT,do_erc=True),
            Pin(num='13',name='S',func=Pin.OPENCOLL,do_erc=True)]),
        Part(name='TNY284P',dest=TEMPLATE,tool=SKIDL,keywords='Energy-Efficient, Off-Line Switcher With Line Compensated Overload Power',description='TinySwitch-4 Family, 28.5W Output Power, PDIP-8C',ref_prefix='U',num_units=1,fplist=['PDIP-8C*'],do_erc=True,aliases=['TNY285P', 'TNY286P', 'TNY287P', 'TNY288P', 'TNY289P', 'TNY290P'],pins=[
            Pin(num='1',name='EN/UV',do_erc=True),
            Pin(num='2',name='BP/M',do_erc=True),
            Pin(num='4',name='D',func=Pin.OPENCOLL,do_erc=True),
            Pin(num='5',name='S',func=Pin.OPENEMIT,do_erc=True),
            Pin(num='6',name='S',func=Pin.OPENEMIT,do_erc=True),
            Pin(num='7',name='S',func=Pin.OPENEMIT,do_erc=True),
            Pin(num='8',name='S',func=Pin.OPENEMIT,do_erc=True)]),
        Part(name='TOP100YN',dest=TEMPLATE,tool=SKIDL,keywords='Three-terminal Off-line PWM Switch',description='TOPSwitch Family, 60W Max Output Power, TO-220',ref_prefix='U',num_units=1,fplist=['TO-220*'],do_erc=True,aliases=['TOP101YN', 'TOP102YN', 'TOP103YN', 'TOP104YN'],pins=[
            Pin(num='1',name='C',do_erc=True),
            Pin(num='2',name='S',func=Pin.OPENEMIT,do_erc=True),
            Pin(num='3',name='D',func=Pin.OPENCOLL,do_erc=True)]),
        Part(name='TOP200YAI',dest=TEMPLATE,tool=SKIDL,keywords='Three-terminal Off-line PWM Switch',description='TOPSwitch Family, 42W Max Output Power, TO-220',ref_prefix='U',num_units=1,fplist=['TO-220*'],do_erc=True,aliases=['TOP201YAI', 'TOP202YAI', 'TOP203YAI', 'TOP204YAI', 'TOP214YAI'],pins=[
            Pin(num='1',name='C',do_erc=True),
            Pin(num='2',name='S',func=Pin.OPENEMIT,do_erc=True),
            Pin(num='3',name='D',func=Pin.OPENCOLL,do_erc=True)]),
        Part(name='TOP209G',dest=TEMPLATE,tool=SKIDL,keywords='Three-terminal Off-line PWM Switch',description='TOPSwitch Family, 5W Max Output Power, SMD-8',ref_prefix='U',num_units=1,fplist=['SMD-8*'],do_erc=True,aliases=['TOP210G'],pins=[
            Pin(num='1',name='S',func=Pin.OPENEMIT,do_erc=True),
            Pin(num='2',name='NC',func=Pin.NOCONNECT,do_erc=True),
            Pin(num='3',name='NC',func=Pin.NOCONNECT,do_erc=True),
            Pin(num='4',name='C',do_erc=True),
            Pin(num='5',name='D',func=Pin.OPENCOLL,do_erc=True),
            Pin(num='6',name='NC',func=Pin.NOCONNECT,do_erc=True),
            Pin(num='7',name='NC',func=Pin.NOCONNECT,do_erc=True),
            Pin(num='8',name='S',func=Pin.OPENEMIT,do_erc=True)]),
        Part(name='TOP209P',dest=TEMPLATE,tool=SKIDL,keywords='Three-terminal Off-line PWM Switch',description='TOPSwitch Family, 5W Max Output Power, DIP-8',ref_prefix='U',num_units=1,fplist=['PDIP-8*'],do_erc=True,aliases=['TOP210PFI'],pins=[
            Pin(num='1',name='S',func=Pin.OPENEMIT,do_erc=True),
            Pin(num='2',name='NC',func=Pin.NOCONNECT,do_erc=True),
            Pin(num='3',name='NC',func=Pin.NOCONNECT,do_erc=True),
            Pin(num='4',name='C',do_erc=True),
            Pin(num='5',name='D',func=Pin.OPENCOLL,do_erc=True),
            Pin(num='6',name='NC',func=Pin.NOCONNECT,do_erc=True),
            Pin(num='7',name='NC',func=Pin.NOCONNECT,do_erc=True),
            Pin(num='8',name='S',func=Pin.OPENEMIT,do_erc=True)]),
        Part(name='TOP252EN',dest=TEMPLATE,tool=SKIDL,keywords='Eco Smart Off-Line Switcher, Extendend Power Range',description='TOPSwitch-HX Family, 254W Output Power',ref_prefix='U',num_units=1,fplist=['eSIP-7C*'],do_erc=True,aliases=['TOP252EG', 'TOP253EG', 'TOP253EN', 'TOP254EG', 'TOP254EN', 'TOP255EG', 'TOP255EN', 'TOP256EG', 'TOP256EN', 'TOP257EG', 'TOP257EN', 'TOP258EG', 'TOP258EN', 'TOP259EG', 'TOP259EN', 'TOP260EG', 'TOP260EN', 'TOP261EG', 'TOP261EN', 'TOP262EN'],pins=[
            Pin(num='1',name='V',do_erc=True),
            Pin(num='2',name='X',do_erc=True),
            Pin(num='3',name='C',do_erc=True),
            Pin(num='4',name='F',func=Pin.PASSIVE,do_erc=True),
            Pin(num='5',name='S',func=Pin.OPENEMIT,do_erc=True),
            Pin(num='7',name='D',func=Pin.OPENCOLL,do_erc=True)]),
        Part(name='TOP252GN',dest=TEMPLATE,tool=SKIDL,keywords='Eco Smart Off-Line Switcher, Extendend Power Range',description='TOPSwitch-HX Family, 35W Output Power',ref_prefix='U',num_units=1,fplist=['SMD-8C*'],do_erc=True,aliases=['TOP253GN', 'TOP254GN', 'TOP255GN', 'TOP256GN', 'TOP257GN', 'TOP258GN'],pins=[
            Pin(num='1',name='M',do_erc=True),
            Pin(num='2',name='C',do_erc=True),
            Pin(num='4',name='D',func=Pin.OPENCOLL,do_erc=True),
            Pin(num='5',name='S',func=Pin.OPENEMIT,do_erc=True),
            Pin(num='6',name='S',func=Pin.OPENEMIT,do_erc=True),
            Pin(num='7',name='S',func=Pin.OPENEMIT,do_erc=True),
            Pin(num='8',name='S',func=Pin.OPENEMIT,do_erc=True)]),
        Part(name='TOP252MN',dest=TEMPLATE,tool=SKIDL,keywords='Eco Smart Off-Line Switcher, Extendend Power Range',description='TOPSwitch-HX Family, 35W Output Power',ref_prefix='U',num_units=1,fplist=['SDIP-10C*'],do_erc=True,aliases=['TOP253MN', 'TOP254MN', 'TOP255MN', 'TOP256MN', 'TOP257MN', 'TOP258MN'],pins=[
            Pin(num='1',name='V',do_erc=True),
            Pin(num='2',name='X',do_erc=True),
            Pin(num='3',name='C',do_erc=True),
            Pin(num='5',name='D',func=Pin.OPENCOLL,do_erc=True),
            Pin(num='6',name='S',func=Pin.OPENEMIT,do_erc=True),
            Pin(num='7',name='S',func=Pin.OPENEMIT,do_erc=True),
            Pin(num='8',name='S',func=Pin.OPENEMIT,do_erc=True),
            Pin(num='9',name='S',func=Pin.OPENEMIT,do_erc=True),
            Pin(num='10',name='S',func=Pin.OPENEMIT,do_erc=True)]),
        Part(name='TOP252PN',dest=TEMPLATE,tool=SKIDL,keywords='Eco Smart Off-Line Switcher, Extendend Power Range',description='TOPSwitch-HX Family, 35W Output Power',ref_prefix='U',num_units=1,fplist=['PDIP-8C*'],do_erc=True,aliases=['TOP253PN', 'TOP254PN', 'TOP255PN', 'TOP256PN', 'TOP257PN', 'TOP258PN'],pins=[
            Pin(num='1',name='M',do_erc=True),
            Pin(num='2',name='C',do_erc=True),
            Pin(num='4',name='D',func=Pin.OPENCOLL,do_erc=True),
            Pin(num='5',name='S',func=Pin.OPENEMIT,do_erc=True),
            Pin(num='6',name='S',func=Pin.OPENEMIT,do_erc=True),
            Pin(num='7',name='S',func=Pin.OPENEMIT,do_erc=True),
            Pin(num='8',name='S',func=Pin.OPENEMIT,do_erc=True)]),
        Part(name='TOP254YN',dest=TEMPLATE,tool=SKIDL,keywords='Eco Smart Off-Line Switcher, Extendend Power Range',description='TOPSwitch-HX Family, 148W Output Power',ref_prefix='U',num_units=1,fplist=['TO-220-7C*'],do_erc=True,aliases=['TOP255YN', 'TOP256YN', 'TOP257YN', 'TOP258YN'],pins=[
            Pin(num='1',name='V',do_erc=True),
            Pin(num='2',name='X',do_erc=True),
            Pin(num='3',name='C',do_erc=True),
            Pin(num='4',name='S',func=Pin.OPENEMIT,do_erc=True),
            Pin(num='5',name='F',func=Pin.PASSIVE,do_erc=True),
            Pin(num='7',name='D',func=Pin.OPENCOLL,do_erc=True)]),
        Part(name='TOP255LN',dest=TEMPLATE,tool=SKIDL,keywords='Eco Smart Off-Line Switcher, Extendend Power Range',description='TOPSwitch-HX Family, 177W Output Power',ref_prefix='U',num_units=1,fplist=['eSIP-7F*'],do_erc=True,aliases=['TOP256LN', 'TOP257LN', 'TOP258LN', 'TOP259LN', 'TOP260LN', 'TOP261LN', 'TOP262LN'],pins=[
            Pin(num='1',name='V',do_erc=True),
            Pin(num='2',name='X',do_erc=True),
            Pin(num='3',name='C',do_erc=True),
            Pin(num='4',name='F',func=Pin.PASSIVE,do_erc=True),
            Pin(num='5',name='S',func=Pin.OPENEMIT,do_erc=True),
            Pin(num='7',name='D',func=Pin.OPENCOLL,do_erc=True)]),
        Part(name='TOP259YN',dest=TEMPLATE,tool=SKIDL,keywords='Eco Smart Off-Line Switcher, Extendend Power Range',description='TOPSwitch-HX Family, 254W Output Power',ref_prefix='U',num_units=1,fplist=['TO-220-7C*'],do_erc=True,aliases=['TOP260YN', 'TOP261YN'],pins=[
            Pin(num='1',name='V',do_erc=True),
            Pin(num='2',name='X',do_erc=True),
            Pin(num='3',name='C',do_erc=True),
            Pin(num='4',name='S',func=Pin.OPENEMIT,do_erc=True),
            Pin(num='5',name='G',func=Pin.PASSIVE,do_erc=True),
            Pin(num='7',name='D',func=Pin.OPENCOLL,do_erc=True)]),
        Part(name='TOP264EG',dest=TEMPLATE,tool=SKIDL,keywords='Integrated Off-Line Switcher with EcoSmart™ Technology',description='TOPSwitch-JX Family, 177W Output Power, eSIP-7C',ref_prefix='U',num_units=1,fplist=['eSIP-7C*'],do_erc=True,aliases=['TOP265EG', 'TOP266EG', 'TOP267EG', 'TOP268EG', 'TOP269EG', 'TOP270EG', 'TOP271EG'],pins=[
            Pin(num='1',name='V',do_erc=True),
            Pin(num='2',name='X',do_erc=True),
            Pin(num='3',name='C',do_erc=True),
            Pin(num='4',name='F',func=Pin.PASSIVE,do_erc=True),
            Pin(num='5',name='S',func=Pin.OPENEMIT,do_erc=True),
            Pin(num='7',name='D',func=Pin.OPENCOLL,do_erc=True)]),
        Part(name='TOP264KG',dest=TEMPLATE,tool=SKIDL,keywords='Integrated Off-Line Switcher with EcoSmart™ Technology',description='TOPSwitch-JX Family, 66W Output Power, eSOP-12B',ref_prefix='U',num_units=1,fplist=['eSOP-12B*'],do_erc=True,aliases=['TOP265KG', 'TOP266KG', 'TOP267KG', 'TOP268KG', 'TOP269KG', 'TOP270KG', 'TOP271KG'],pins=[
            Pin(num='1',name='V',do_erc=True),
            Pin(num='2',name='X',do_erc=True),
            Pin(num='3',name='C',do_erc=True),
            Pin(num='4',name='F',func=Pin.PASSIVE,do_erc=True),
            Pin(num='6',name='D',func=Pin.OPENCOLL,do_erc=True),
            Pin(num='7',name='S',func=Pin.OPENEMIT,do_erc=True),
            Pin(num='8',name='S',func=Pin.OPENEMIT,do_erc=True),
            Pin(num='9',name='S',func=Pin.OPENEMIT,do_erc=True),
            Pin(num='10',name='S',func=Pin.OPENEMIT,do_erc=True),
            Pin(num='11',name='S',func=Pin.OPENEMIT,do_erc=True),
            Pin(num='12',name='S',func=Pin.OPENEMIT,do_erc=True)]),
        Part(name='TOP264VG',dest=TEMPLATE,tool=SKIDL,keywords='Integrated Off-Line Switcher with EcoSmart™ Technology',description='TOPSwitch-JX Family, 177W Output Power, eDIP-12B',ref_prefix='U',num_units=1,fplist=['eDIP-12*'],do_erc=True,aliases=['TOP265VG', 'TOP266VG', 'TOP267VG', 'TOP268VG', 'TOP269VG', 'TOP270VG', 'TOP271VG'],pins=[
            Pin(num='1',name='V',do_erc=True),
            Pin(num='2',name='X',do_erc=True),
            Pin(num='3',name='C',do_erc=True),
            Pin(num='4',name='F',func=Pin.PASSIVE,do_erc=True),
            Pin(num='6',name='D',func=Pin.OPENCOLL,do_erc=True),
            Pin(num='7',name='S',func=Pin.OPENEMIT,do_erc=True),
            Pin(num='8',name='S',func=Pin.OPENEMIT,do_erc=True),
            Pin(num='9',name='S',func=Pin.OPENEMIT,do_erc=True),
            Pin(num='10',name='S',func=Pin.OPENEMIT,do_erc=True),
            Pin(num='11',name='S',func=Pin.OPENEMIT,do_erc=True),
            Pin(num='12',name='S',func=Pin.OPENEMIT,do_erc=True)])])


from skidl import Pin, Part, SchLib, SKIDL, TEMPLATE

SKIDL_lib_version = '0.0.1'

mechanical = SchLib(tool=SKIDL).add_parts(*[
        Part(name='Heatsink',dest=TEMPLATE,tool=SKIDL,keywords='thermal heat temperature',description='Heatsink',ref_prefix='HS',num_units=1,do_erc=True),
        Part(name='Heatsink_PAD',dest=TEMPLATE,tool=SKIDL,keywords='thermal heat temperature',description='Heatsink with electrical connection',ref_prefix='HS',num_units=1,do_erc=True,pins=[
            Pin(num='1',name='~',func=Pin.PASSIVE,do_erc=True)]),
        Part(name='Housing',dest=TEMPLATE,tool=SKIDL,keywords='housing',description='Housing',ref_prefix='MK',num_units=1,do_erc=True),
        Part(name='Housing_PAD',dest=TEMPLATE,tool=SKIDL,keywords='housing',description='Housing with connection pin',ref_prefix='MK',num_units=1,do_erc=True,pins=[
            Pin(num='1',name='PAD',do_erc=True)]),
        Part(name='Mounting_Hole',dest=TEMPLATE,tool=SKIDL,keywords='mounting hole',description='Mounting Hole without connection',ref_prefix='MK',num_units=1,fplist=['Mounting?Hole*', 'Hole*'],do_erc=True),
        Part(name='Mounting_Hole_PAD',dest=TEMPLATE,tool=SKIDL,keywords='mounting hole',description='Mounting Hole with connection',ref_prefix='MK',num_units=1,fplist=['Mounting?Hole*', 'Hole*'],do_erc=True,pins=[
            Pin(num='1',name='1',do_erc=True)])])


from skidl import Pin, Part, SchLib, SKIDL, TEMPLATE

SKIDL_lib_version = '0.0.1'

triac_thyristor = SchLib(tool=SKIDL).add_parts(*[
        Part(name='BT169B',dest=TEMPLATE,tool=SKIDL,keywords='thyristor logic level',description='0.5A Ion, 600V Voff, Thyristors logic level, Silicon Controlled Rectifier (Thyristor), TO-92',ref_prefix='Q',num_units=1,fplist=['TO?92*Inline*Narrow*'],do_erc=True,aliases=['BT169D', 'BT169G'],pins=[
            Pin(num='1',name='A',func=Pin.PASSIVE,do_erc=True),
            Pin(num='2',name='G',do_erc=True),
            Pin(num='3',name='K',func=Pin.PASSIVE,do_erc=True)]),
        Part(name='TIC106',dest=TEMPLATE,tool=SKIDL,keywords='thyristor',description='12A Ion, 400-800V Voff, Silicon Controlled Rectifier (Thyristor), TO-220',ref_prefix='Q',num_units=1,fplist=['TO?220*'],do_erc=True,aliases=['TIC116', 'TIC126'],pins=[
            Pin(num='1',name='K',func=Pin.PASSIVE,do_erc=True),
            Pin(num='2',name='A',func=Pin.PASSIVE,do_erc=True),
            Pin(num='3',name='G',do_erc=True)]),
        Part(name='TIC226',dest=TEMPLATE,tool=SKIDL,keywords='Triac',description='8A RMS, 400-800V Off-State Voltage, Triac, TO-220',ref_prefix='Q',num_units=1,fplist=['TO?220*'],do_erc=True,aliases=['TIC206', 'BT138-600', 'BT138-800', 'TIC216', 'BT136-500', 'BT136-600', 'BT136-800', 'BT139-600'],pins=[
            Pin(num='1',name='A1',func=Pin.PASSIVE,do_erc=True),
            Pin(num='2',name='A2',func=Pin.PASSIVE,do_erc=True),
            Pin(num='3',name='G',do_erc=True)]),
        Part(name='Z0103MN',dest=TEMPLATE,tool=SKIDL,keywords='4Q Triac',description='4Q Triac, 1A RMS, 800V VDRM, 25mA Igt, 25mA Ih, SOT-223',ref_prefix='D',num_units=1,fplist=['SOT*223*'],do_erc=True,aliases=['Z0103NN', 'Z0107MN', 'Z0107NN', 'Z0109MN', 'Z0109NN', 'Z0110MN', 'Z0110NN'],pins=[
            Pin(num='1',name='A1',func=Pin.PASSIVE,do_erc=True),
            Pin(num='2',name='A2',func=Pin.PASSIVE,do_erc=True),
            Pin(num='3',name='G',do_erc=True),
            Pin(num='4',name='A4',func=Pin.PASSIVE,do_erc=True)])])


from skidl import Pin, Part, SchLib, SKIDL, TEMPLATE

SKIDL_lib_version = '0.0.1'

intfc_brd_lib = SchLib(tool=SKIDL).add_parts(*[
        Part(name='TPS793XX',dest=TEMPLATE,tool=SKIDL,skidl_trace='C:\\xesscorp\\PRODUCTS\\INACTIVE\\XuLA_Developmental\\fmw\\intfc_brd\\intfc_brd.py#20',ref_prefix='U',num_units=1,do_erc=True,footprint='TO_SOT_Packages_SMD:SOT-23-5',pins=[
            Pin(num='1',name='IN',func=Pin.PWRIN,do_erc=True),
            Pin(num='2',name='GND',func=Pin.PWRIN,do_erc=True),
            Pin(num='3',name='EN',do_erc=True),
            Pin(num='4',name='NR',func=Pin.OUTPUT,do_erc=True),
            Pin(num='5',name='OUT',func=Pin.PWROUT,do_erc=True)]),
        Part(name='C',dest=TEMPLATE,tool=SKIDL,skidl_trace='C:\\xesscorp\\PRODUCTS\\INACTIVE\\XuLA_Developmental\\fmw\\intfc_brd\\intfc_brd.py#21',keywords='cap capacitor',description='Unpolarized capacitor',ref_prefix='C',num_units=1,fplist=['C_*'],do_erc=True,footprint='Capacitors_SMD:C_0603',pins=[
            Pin(num='1',name='~',func=Pin.PASSIVE,do_erc=True),
            Pin(num='2',name='~',func=Pin.PASSIVE,do_erc=True)]),
        Part(name='PIC32MX2*0F***B-QFN28',dest=TEMPLATE,tool=SKIDL,skidl_trace='C:\\xesscorp\\PRODUCTS\\INACTIVE\\XuLA_Developmental\\fmw\\intfc_brd\\intfc_brd.py#30',ref_prefix='U',num_units=1,do_erc=True,footprint='Housings_DFN_QFN:QFN-28-1EP_6x6mm_Pitch0.65mm',pins=[
            Pin(num='15',name='TDO/RPB9/SDA1/CTED4/PMD3/RB9',func=Pin.BIDIR,do_erc=True),
            Pin(num='16',name='VSS',func=Pin.PWRIN,do_erc=True),
            Pin(num='17',name='VCAP',func=Pin.PWROUT,do_erc=True),
            Pin(num='18',name='PGED2/RPB10/D+/CTED11/RB10',func=Pin.BIDIR,do_erc=True),
            Pin(num='19',name='PGEC2/RPB11/D-/RB11',func=Pin.BIDIR,do_erc=True),
            Pin(num='20',name='VUSB3V3',func=Pin.PWRIN,do_erc=True),
            Pin(num='21',name='AN11/RPB13/CTPLS/PMRD/RB13',func=Pin.BIDIR,do_erc=True),
            Pin(num='22',name='CVREFOUT/AN10/C3INB/RPB14/VBUSON/SCK1/CTED5/RB14',func=Pin.BIDIR,do_erc=True),
            Pin(num='23',name='AN9/C3INA/RPB15/SCK2/CTED6/PMCS1/RB15',func=Pin.BIDIR,do_erc=True),
            Pin(num='24',name='AVSS',func=Pin.PWRIN,do_erc=True),
            Pin(num='25',name='AVDD',func=Pin.PWRIN,do_erc=True),
            Pin(num='26',name='~MCLR',do_erc=True),
            Pin(num='27',name='PGED3/VREF+/CVREF+/AN0/C3INC/RPA0/CTED1/PMD7/RA0',func=Pin.BIDIR,do_erc=True),
            Pin(num='28',name='PGEC3/VREF-/CVREF-/AN1/RPA1/CTED2/PMD6/RA1',func=Pin.BIDIR,do_erc=True),
            Pin(num='29',name='PAD',func=Pin.PWRIN,do_erc=True),
            Pin(num='1',name='PGED1/AN2/C1IND/C2INB/C3IND/RPB0/PMD0/RB0',func=Pin.BIDIR,do_erc=True),
            Pin(num='2',name='PGEC1/AN3/C1INC/C2INA/RPB1/CTED12/PMD1/RB1',func=Pin.BIDIR,do_erc=True),
            Pin(num='3',name='AN4/C1INB/C2IND/RPB2/SDA2/CTED13/PMD2/RB2',func=Pin.BIDIR,do_erc=True),
            Pin(num='4',name='AN5/C1INA/C2INC/RTCC/RPB3/SCL2/PMWR/RB3',func=Pin.BIDIR,do_erc=True),
            Pin(num='5',name='VSS',func=Pin.PWRIN,do_erc=True),
            Pin(num='6',name='OSC1/CLKI/RPA2/RA2',func=Pin.BIDIR,do_erc=True),
            Pin(num='7',name='OSC2/CLKO/RPA3/PMA0/RA3',func=Pin.BIDIR,do_erc=True),
            Pin(num='8',name='SOSCI/RPB4/RB4',func=Pin.BIDIR,do_erc=True),
            Pin(num='9',name='SOSCO/RPA4/T1CK/CTED9/PMA1/RA4',func=Pin.BIDIR,do_erc=True),
            Pin(num='10',name='VDD',func=Pin.PWRIN,do_erc=True),
            Pin(num='11',name='TMS/RPB5/USBID/RB5',func=Pin.BIDIR,do_erc=True),
            Pin(num='12',name='VBUS',do_erc=True),
            Pin(num='13',name='TDI/RPB7/CTED3/PMD5/INT0/RB7',func=Pin.BIDIR,do_erc=True),
            Pin(num='14',name='TCK/RPB8/SCL1/CTED10/PMD4/RB8',func=Pin.BIDIR,do_erc=True)]),
        Part(name='R',dest=TEMPLATE,tool=SKIDL,skidl_trace='C:\\xesscorp\\PRODUCTS\\INACTIVE\\XuLA_Developmental\\fmw\\intfc_brd\\intfc_brd.py#47',keywords='r res resistor',description='Resistor',ref_prefix='R',num_units=1,fplist=['R_*', 'R_*'],do_erc=True,footprint='Resistors_SMD:R_0603',pins=[
            Pin(num='1',name='~',func=Pin.PASSIVE,do_erc=True),
            Pin(num='2',name='~',func=Pin.PASSIVE,do_erc=True)]),
        Part(name='USB-MicroB',dest=TEMPLATE,tool=SKIDL,skidl_trace='C:\\xesscorp\\PRODUCTS\\INACTIVE\\XuLA_Developmental\\fmw\\intfc_brd\\intfc_brd.py#55',keywords='USB, USBB, connector',description='USB Micro-B connector',ref_prefix='USB',num_units=1,do_erc=True,footprint='XESS:USB-microB-1',pins=[
            Pin(num='1',name='VBUS',func=Pin.PWROUT,do_erc=True),
            Pin(num='2',name='D-',func=Pin.BIDIR,do_erc=True),
            Pin(num='3',name='D+',func=Pin.BIDIR,do_erc=True),
            Pin(num='4',name='NC',func=Pin.NOCONNECT,do_erc=True),
            Pin(num='5',name='GND',func=Pin.PWROUT,do_erc=True),
            Pin(num='SH',name='SHIELD',func=Pin.PASSIVE,do_erc=True)]),
        Part(name='LED',dest=TEMPLATE,tool=SKIDL,skidl_trace='C:\\xesscorp\\PRODUCTS\\INACTIVE\\XuLA_Developmental\\fmw\\intfc_brd\\intfc_brd.py#65',keywords='led diode',description='LED generic',ref_prefix='D',num_units=1,fplist=['LED*'],do_erc=True,footprint='Diodes_SMD:D_0603',pins=[
            Pin(num='1',name='K',func=Pin.PASSIVE,do_erc=True),
            Pin(num='2',name='A',func=Pin.PASSIVE,do_erc=True)]),
        Part(name='XTAL4',dest=TEMPLATE,tool=SKIDL,skidl_trace='C:\\xesscorp\\PRODUCTS\\INACTIVE\\XuLA_Developmental\\fmw\\intfc_brd\\intfc_brd.py#71',ref_prefix='Y',num_units=1,do_erc=True,footprint='XESS:32x25-4',pins=[
            Pin(num='1',name='~',func=Pin.PASSIVE,do_erc=True),
            Pin(num='2',name='~',func=Pin.PASSIVE,do_erc=True),
            Pin(num='3',name='~',func=Pin.PASSIVE,do_erc=True),
            Pin(num='4',name='~',func=Pin.PASSIVE,do_erc=True)]),
        Part(name='PICkit3_hdr',dest=TEMPLATE,tool=SKIDL,skidl_trace='C:\\xesscorp\\PRODUCTS\\INACTIVE\\XuLA_Developmental\\fmw\\intfc_brd\\intfc_brd.py#79',ref_prefix='U',num_units=1,do_erc=True,footprint='Pin_Headers:Pin_Header_Straight_1x06',pins=[
            Pin(num='1',name='~MCLR',func=Pin.OUTPUT,do_erc=True),
            Pin(num='2',name='VDD',func=Pin.PWRIN,do_erc=True),
            Pin(num='3',name='GND',func=Pin.PWRIN,do_erc=True),
            Pin(num='4',name='PGD',func=Pin.BIDIR,do_erc=True),
            Pin(num='5',name='PGC',func=Pin.BIDIR,do_erc=True),
            Pin(num='6',name='NC',func=Pin.NOCONNECT,do_erc=True)]),
        Part(name='Conn_01x06',dest=TEMPLATE,tool=SKIDL,skidl_trace='C:\\xesscorp\\PRODUCTS\\INACTIVE\\XuLA_Developmental\\fmw\\intfc_brd\\intfc_brd.py#88',keywords='connector',description='Generic connector, single row, 01x06',ref_prefix='J',num_units=1,fplist=['Connector*:*_??x*mm*', 'Connector*:*1x??x*mm*', 'Pin?Header?Straight?1X*', 'Pin?Header?Angled?1X*', 'Socket?Strip?Straight?1X*', 'Socket?Strip?Angled?1X*'],do_erc=True,footprint='Pin_Headers:Pin_Header_Straight_1x06',pins=[
            Pin(num='1',name='Pin_1',func=Pin.PASSIVE,do_erc=True),
            Pin(num='2',name='Pin_2',func=Pin.PASSIVE,do_erc=True),
            Pin(num='3',name='Pin_3',func=Pin.PASSIVE,do_erc=True),
            Pin(num='4',name='Pin_4',func=Pin.PASSIVE,do_erc=True),
            Pin(num='5',name='Pin_5',func=Pin.PASSIVE,do_erc=True),
            Pin(num='6',name='Pin_6',func=Pin.PASSIVE,do_erc=True)])])